@@ -54,12 +54,13 @@ r2_nagelkerke <- function(model, ...) {
 
 #' @export
 r2_nagelkerke.glm <- function(model, verbose = TRUE, ...) {
-  if (is.null(info <- list(...)$model_info)) {
+  info <- list(...)$model_info
+  if (is.null(info)) {
     info <- suppressWarnings(insight::model_info(model, verbose = FALSE))
   }
   if (info$is_binomial && !info$is_bernoulli && class(model)[1] == "glm") {
     if (verbose) {
-      warning(insight::format_message("Can't calculate accurate R2 for binomial models that are not Bernoulli models."), call. = FALSE)
+      insight::format_warning("Can't calculate accurate R2 for binomial models that are not Bernoulli models.")
     }
     return(NULL)
   } else {
@@ -76,6 +77,26 @@ r2_nagelkerke.glm <- function(model, verbose = TRUE, ...) {
 #' @export
 r2_nagelkerke.BBreg <- r2_nagelkerke.glm
 
+
+#' @export
+r2_nagelkerke.nestedLogit <- function(model, ...) {
+  n <- insight::n_obs(model, disaggregate = TRUE)
+  stats::setNames(
+    lapply(names(model$models), function(i) {
+      m <- model$models[[i]]
+      # if no deviance, return NA
+      if (is.null(m$deviance)) {
+        return(NA)
+      }
+      r2_nagelkerke <- (1 - exp((m$deviance - m$null.deviance) / n[[i]])) / (1 - exp(-m$null.deviance / n[[i]]))
+      names(r2_nagelkerke) <- "Nagelkerke's R2"
+      r2_nagelkerke
+    }),
+    names(model$models)
+  )
+}
+
+
 #' @export
 r2_nagelkerke.bife <- function(model, ...) {
   r2_nagelkerke <- r2_coxsnell(model) / (1 - exp(-model$null_deviance / insight::n_obs(model)))
@@ -154,9 +175,6 @@ r2_nagelkerke.glmx <- r2_nagelkerke.clm
 #' @export
 r2_nagelkerke.brmultinom <- r2_nagelkerke.clm
 
-#' @export
-r2_nagelkerke.mclogit <- r2_nagelkerke.clm
-
 #' @export
 r2_nagelkerke.censReg <- r2_nagelkerke.clm
 
@@ -188,3 +206,24 @@ r2_nagelkerke.svycoxph <- function(model, ...) {
   l_base <- model$ll[1]
   .r2_nagelkerke(model, l_base)
 }
+
+
+# other ---------------------
+
+#' @export
+r2_nagelkerke.mclogit <- function(model, ...) {
+  insight::check_if_installed("mclogit", reason = "to calculate R2")
+  s <- mclogit::getSummary.mclogit(model)
+  r2_nagelkerke <- s$sumstat["Nagelkerke"]
+  names(r2_nagelkerke) <- "Nagelkerke's R2"
+  r2_nagelkerke
+}
+
+#' @export
+r2_nagelkerke.mblogit <- function(model, ...) {
+  insight::check_if_installed("mclogit", reason = "to calculate R2")
+  s <- mclogit::getSummary.mblogit(model)
+  r2_nagelkerke <- s$sumstat["Nagelkerke"]
+  names(r2_nagelkerke) <- "Nagelkerke's R2"
+  r2_nagelkerke
+}
